@@ -55,6 +55,11 @@ class RoleForm extends RepositoryForm
         return Filter::where('name', $this->getIdentifier());
     }
 
+    public function filterName($value, $allowBrackets = false)
+    {
+        return parent::filterName($value, $allowBrackets) . '_element';
+    }
+
     public function createInsertElements(array $formData = array())
     {
         $this->addElement(
@@ -156,7 +161,7 @@ class RoleForm extends RepositoryForm
                 if (! isset($spec['isFullPerm'])
                     && substr($name, 0, strlen(self::DENY_PREFIX)) !== self::DENY_PREFIX
                 ) {
-                    $denyCheckbox = $this->createElement('checkbox', self::DENY_PREFIX . $name, [
+                    $denyCheckbox = $this->createElement('checkbox', $this->filterName(self::DENY_PREFIX . $name), [
                         'decorators'    => ['ViewHelper']
                     ]);
                     $this->addElement($denyCheckbox);
@@ -257,7 +262,7 @@ class RoleForm extends RepositoryForm
                                     PREG_SPLIT_DELIM_CAPTURE|PREG_SPLIT_NO_EMPTY
                                 )))),
                             'description'   => $spec['description'],
-                            'style'         => $isUnrestricted ? 'text-decoration:line-through;' : '',
+                            'class'         => $isUnrestricted ? 'unrestricted-role' : '',
                             'readonly'      => $isUnrestricted ?: null
                         ]
                     )
@@ -272,7 +277,7 @@ class RoleForm extends RepositoryForm
                 $moduleName . '_header',
                 [
                     'decorators'    => ['ViewHelper'],
-                    'value'         => '<h3>'
+                    'value'         => '<summary class="collapsible-control">'
                         . '<span>' . ($moduleName !== 'application'
                             ? sprintf('%s <em>%s</em>', $moduleName, $this->translate('Module'))
                             :  'Icinga Web 2'
@@ -285,18 +290,20 @@ class RoleForm extends RepositoryForm
                             : ''
                         )
                         . '</span>'
-                        . '</h3>'
+                        . new Icon('angles-down', ['class' => 'collapse-icon'])
+                        . new Icon('angles-left', ['class' => 'expand-icon'])
+                        . '</summary>'
                 ]
             );
 
             $this->addDisplayGroup($elements, $moduleName . '_elements', [
                 'decorators'    => [
                     'FormElements',
-                    ['Fieldset', [
-                        'class'                 => 'collapsible',
-                        'data-toggle-element'   => 'h3',
-                        'data-visible-height'   => 0
-                    ]]
+                    ['HtmlTag', [
+                        'tag'   => 'details',
+                        'class' => 'collapsible'
+                    ]],
+                    ['Fieldset']
                 ]
             ]);
         }
@@ -319,7 +326,7 @@ class RoleForm extends RepositoryForm
             'users'             => $role->users,
             'groups'            => $role->groups,
             'unrestricted'      => $role->unrestricted,
-            self::WILDCARD_NAME => (bool) preg_match('~(?>^|,)\*(?>$|,)~', $role->permissions)
+            self::WILDCARD_NAME => $role->permissions && preg_match('~(?>^|,)\*(?>$|,)~', $role->permissions)
         ];
 
         if (! empty($role->permissions) || ! empty($role->refusals)) {
@@ -448,7 +455,7 @@ class RoleForm extends RepositoryForm
                 $b = array_shift($bParts);
             } while ($a === $b);
 
-            return strnatcmp($a, $b);
+            return strnatcmp($a ?? '', $b ?? '');
         });
     }
 
@@ -574,6 +581,9 @@ class RoleForm extends RepositoryForm
             ],
             'application/sessions' => [
                 'description' => t('Allow to manage user sessions')
+            ],
+            'application/migrations' => [
+                'description' => t('Allow to apply pending application migrations')
             ]
         ];
 
