@@ -370,9 +370,9 @@ class ListController extends Controller
             array('day', $form->getValue('state'))
         );
         $this->params->remove(array('objecttype', 'from', 'to', 'state', 'btn_submit'));
-        $this->view->filter = Filter::fromQuerystring((string) $this->params);
+        $this->view->filter = Filter::fromQueryString((string) $this->params);
         $query->applyFilter($this->view->filter);
-        $query->applyFilter(Filter::fromQuerystring('timestamp>=' . $from));
+        $query->applyFilter(Filter::fromQueryString('timestamp>=' . $from));
         $this->applyRestriction('monitoring/filter/objects', $query);
         $this->view->summary = $query;
         $this->view->column = $form->getValue('state');
@@ -803,6 +803,6 @@ class ListController extends Controller
      */
     private function createTabs()
     {
-        $this->getTabs()->extend(new OutputFormat())->extend(new DashboardAction())->extend(new MenuAction());
+        return $this->getTabs()->extend(new OutputFormat())->extend(new DashboardAction())->extend(new MenuAction());
     }
 }
