@@ -10,6 +10,8 @@ use Icinga\Module\Monitoring\Command\IcingaCommand;
  */
 class DeleteDowntimeCommand extends IcingaCommand
 {
+    use CommandAuthor;
+
     /**
      * ID of the downtime that is to be deleted
      *
@@ -17,6 +19,15 @@ class DeleteDowntimeCommand extends IcingaCommand
      */
     protected $downtimeId;
 
+    /**
+     * Name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @var string
+     */
+    protected $downtimeName;
+
     /**
      * Whether the command affects a service downtime
      *
@@ -47,6 +58,33 @@ class DeleteDowntimeCommand extends IcingaCommand
         return $this;
     }
 
+    /**
+     * Get the name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @return string
+     */
+    public function getDowntimeName()
+    {
+        return $this->downtimeName;
+    }
+
+    /**
+     * Set the name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @param   string  $downtimeName
+     *
+     * @return  $this
+     */
+    public function setDowntimeName($downtimeName)
+    {
+        $this->downtimeName = $downtimeName;
+        return $this;
+    }
+
     /**
      * Get whether the command affects a service
      *
