@@ -23,6 +23,9 @@ class ScheduleHostDowntimeCommand extends ScheduleServiceDowntimeCommand
      */
     protected $forAllServices = false;
 
+    /** @var bool Whether to send the all_services API parameter */
+    protected $forAllServicesNative;
+
     /**
      * Set whether to schedule a downtime for all services associated with a particular host
      *
@@ -45,4 +48,28 @@ class ScheduleHostDowntimeCommand extends ScheduleServiceDowntimeCommand
     {
         return $this->forAllServices;
     }
+
+    /**
+     * Get whether to send the all_services API parameter
+     *
+     * @return bool
+     */
+    public function isForAllServicesNative()
+    {
+        return $this->forAllServicesNative;
+    }
+
+    /**
+     * Get whether to send the all_services API parameter
+     *
+     * @param bool $forAllServicesNative
+     *
+     * @return $this
+     */
+    public function setForAllServicesNative($forAllServicesNative = true)
+    {
+        $this->forAllServicesNative = (bool) $forAllServicesNative;
+
+        return $this;
+    }
 }
