@@ -3,11 +3,14 @@
 
 namespace Icinga\Module\Monitoring;
 
+use ArrayIterator;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\QueryException;
 use Icinga\Data\Filter\Filter;
 use Icinga\Data\Filterable;
 use Icinga\File\Csv;
+use Icinga\Module\Monitoring\Backend\MonitoringBackend;
+use Icinga\Module\Monitoring\Data\CustomvarProtectionIterator;
 use Icinga\Util\Json;
 use Icinga\Web\Controller as IcingaWebController;
 use Icinga\Web\Url;
@@ -20,13 +23,13 @@ class Controller extends IcingaWebController
     /**
      * The backend used for this controller
      *
-     * @var Backend
+     * @var MonitoringBackend
      */
     protected $backend;
 
     protected function moduleInit()
     {
-        $this->backend = Backend::createBackend($this->_getParam('backend'));
+        $this->backend = MonitoringBackend::instance($this->_getParam('backend'));
         $this->view->url = Url::fromRequest();
     }
 
@@ -60,7 +63,15 @@ class Controller extends IcingaWebController
                         'Content-Disposition',
                         'inline; filename=' . $this->getRequest()->getActionName() . '.json'
                     )
-                    ->appendBody(Json::sanitize($query->fetchAll()))
+                    ->appendBody(
+                        Json::sanitize(
+                            iterator_to_array(
+                                new CustomvarProtectionIterator(
+                                    new ArrayIterator($query->fetchAll())
+                                )
+                            )
+                        )
+                    )
                     ->sendResponse();
                 exit;
             case 'csv':
@@ -72,7 +83,7 @@ class Controller extends IcingaWebController
                         'Content-Disposition',
                         'attachment; filename=' . $this->getRequest()->getActionName() . '.csv'
                     )
-                    ->appendBody((string) Csv::fromQuery($query))
+                    ->appendBody((string) Csv::fromQuery(new CustomvarProtectionIterator($query)))
                     ->sendResponse();
                 exit;
         }
@@ -97,7 +108,7 @@ class Controller extends IcingaWebController
      *
      * @param   string $name        Name of the restriction
      *
-     * @return  Filter|null         Filter object or null if the authenticated user is not restricted
+     * @return  Filter              Filter object
      * @throws  ConfigurationError  If the restriction contains invalid filter columns
      */
     protected function getRestriction($name)
@@ -115,7 +126,7 @@ class Controller extends IcingaWebController
         ));
         foreach ($this->getRestrictions($name) as $filter) {
             if ($filter === '*') {
-                return Filter::matchAny();
+                return Filter::matchAll();
             }
             try {
                 $restriction->addFilter(Filter::fromQueryString($filter));
@@ -138,6 +149,11 @@ class Controller extends IcingaWebController
                 );
             }
         }
+
+        if ($restriction->isEmpty()) {
+            return Filter::matchAll();
+        }
+
         return $restriction;
     }
 }
